clear all;close all;clc;
Nt = 32;
Nr = 1;
fc = 1.5e9;
c = 3e8;
lambda_c = c/fc;
d = lambda_c / 2;
eps = 1e-3;

D = 0.5 * Nt^2 * lambda_c;

num_r = 500;
num_theta = 500;
r_start = 1.5;
r_end = 30;


r_list = linspace(r_start, r_end, num_r);
theta_list = linspace(-pi/3, pi/3, num_theta);
x_list = r_list.' * cos(theta_list);
y_list = r_list.' * sin(theta_list);

num_subfig = 3;
g = zeros(num_subfig, num_r, num_theta);

r_center = [4,8,25];

for i_subfig = 1:3
    r = r_center(i_subfig);
    theta = 0;
    H = near_field_manifold(Nt, d, fc, r, theta);
    w = narrow_focus(H,Nt);
    for idx_r = 1:num_r
        for idx_theta = 1:num_theta
            H = near_field_manifold(Nt, d, fc, r_list(idx_r), theta_list(idx_theta));
            g(i_subfig, idx_r, idx_theta)=  abs(H*w)/norm(H);
        end
    end
end

figure;
t = tiledlayout(1,3);
t.TileSpacing = 'compact';
t.Padding = 'compact';

%% fig 1
nexttile
hold on;
mesh(x_list,y_list,squeeze(g(1,:,:)));
p1 = plot3(r_center(1)*cos(theta), r_center(1)*sin(theta), 1, 'o', 'markersize', 8, 'LineWidth',2, 'color', 'r');
p2 = plot3(r_center(2)*cos(theta), r_center(2)*sin(theta), 1, '^', 'markersize', 8, 'LineWidth',2, 'color', 'm');
p3 = plot3(r_center(3)*cos(theta), r_center(3)*sin(theta), 1, 's', 'markersize', 8, 'LineWidth',2, 'color', 'k');
grid('off');
box on;
xlim([0 32]);

%% fig 2
nexttile
hold on;
mesh(x_list,y_list,squeeze(g(2,:,:)));
p1 = plot3(r_center(1)*cos(theta), r_center(1)*sin(theta), 1, 'o', 'markersize', 8, 'LineWidth',2, 'color', 'r');
p2 = plot3(r_center(2)*cos(theta), r_center(2)*sin(theta), 1, '^', 'markersize', 8, 'LineWidth',2, 'color', 'm');
p3 = plot3(r_center(3)*cos(theta), r_center(3)*sin(theta), 1, 's', 'markersize', 8, 'LineWidth',2, 'color', 'k');
grid('off');
box on;
xlim([0 32]);
legend([p1,p2,p3], {'Location of User 1    ','Location of User 2    ','Location of User 3    '}, 'fontname', 'Helvetica',...
    'fontsize', 14,'location','northoutside','NumColumns',3, 'interpreter', 'latex');
% xlable('x-axis [m]');

%% fig 3
nexttile
hold on;
mesh(x_list,y_list,squeeze(g(3,:,:)));
p1 = plot3(r_center(1)*cos(theta), r_center(1)*sin(theta), 1, 'o', 'markersize', 8, 'LineWidth',2, 'color', 'r');
p2 = plot3(r_center(2)*cos(theta), r_center(2)*sin(theta), 1, '^', 'markersize', 8, 'LineWidth',2, 'color', 'm');
p3 = plot3(r_center(3)*cos(theta), r_center(3)*sin(theta), 1, 's', 'markersize', 8, 'LineWidth',2, 'color', 'k');
grid('off')
box on;
xlim([0 32]);

xlabel(t,'{\emph{x}}-axis [m]', 'interpreter', 'latex', 'fontsize', 14)
ylabel(t, '{\emph{y}}-axis [m]', 'interpreter', 'latex', 'fontsize', 14);

colorbar
colormap('Jet')